@@ -84,7 +84,7 @@ def run():
 # Creating command
 @run.command(name='run')
 @click.option('--testrun_id','-id', required=True)
-@click.option('--wait_time','-w', default=30, required=False)
+@click.option('--wait_time','-w',required=False)
 @click.option('--git_pass','-p', required=False)
 def run(testrun_id, git_pass, wait_time):
     """If this command is run with testrun id as an argument, aitest CLI will create new test for you with same configuration of provided testrun id.Enter git password with -p only if you used git url of the automation code for creating the test otherwise no need to enter git password.
@@ -149,31 +149,45 @@ def run(testrun_id, git_pass, wait_time):
         exit()
     if res2.status_code==200:
         res_body=res2.json() 
-        test_data=json.loads(res_body['body'])
-        click.echo(f"\nTest created successfully\nTest Name : {test_data['load_test_details']['testrun_name']}\nTestrun ID : {test_data['load_test_details']['testrun_id']}\n")
-        click.echo("Testrun is in progress, result will be displayed once it get completed.")
-        new_time = datetime.now() +timedelta(minutes=int(wait_time))
-        test_status=""
-        while test_status!="completed":
-            if (new_time.strftime("%H:%M:%S"))==(datetime.now().strftime("%H:%M:%S")):
-                click.echo(f"The request is timed out. The testrun is still in progress. To see the status of the testrun, please run command : [ aitest status {test_data['load_test_details']['testrun_id']} ].")
-                exit()
-            base_url = f"https://api.aitest.dev.appliedaiconsulting.com/public/v1/testrun_result/status/{test_data['load_test_details']['testrun_id']}"
-            status_res =requests.get(base_url,headers=headers)
-            status_test_data=status_res.json()
-            body=json.loads(status_test_data['body'])
-            test_status = body['testrun_status'] 
-            if test_status=="completed":
-                testrun_status_details=body['testrun_status_details']
-                table = PrettyTable(["browser_name", "browser_version","test run result id", "status", "time taken"])
-                click.echo(f"\ntest status : {test_status}\n")
-                for i in testrun_status_details:
-                    table.add_row([i['browser_name'],i['browser_version'],i['testrun_result_id'],i['testrun_result_status'],i['time_taken']])
-                click.echo(table)            
-        return 1
+        try:
+            test_data=json.loads(res_body['body'])
+        except:
+            click.echo(res_body)
+            exit(-1)
+        click.echo(f"\nTestrun created successfully\nTestrun Name : {test_data['load_test_details']['testrun_name']}\nTestrun ID : {test_data['load_test_details']['testrun_id']}\n")
+        if wait_time:
+            click.echo("Testrun is in progress, result will be displayed once it get completed.")
+            new_time = datetime.now() +timedelta(minutes=int(wait_time))
+            test_status=""
+            while test_status!="completed":
+                if (new_time.strftime("%H:%M:%S"))==(datetime.now().strftime("%H:%M:%S")):
+                    click.echo(f"The request is timed out. The testrun is still in progress. To see the status of the testrun, please run command : [ aitest status {test_data['load_test_details']['testrun_id']} ].")
+                    exit()
+                base_url = f"https://api.aitest.dev.appliedaiconsulting.com/public/v1/testrun_result/status/{test_data['load_test_details']['testrun_id']}"
+                status_res =requests.get(base_url,headers=headers)
+                status_test_data=status_res.json()
+                body=json.loads(status_test_data['body'])
+                test_status = body['testrun_status'] 
+                if test_status=="completed":
+                    testrun_status_details=body['testrun_status_details']
+                    table = PrettyTable(["browser_name", "browser_version","test run result id", "status", "time taken"])
+                    click.echo(f"\ntest status : {test_status}\n")
+                    fail_count = 0
+                    for i in testrun_status_details:
+                        if i['testrun_result_status']=="fail":
+                            fail_count+=1
+                        table.add_row([i['browser_name'],i['browser_version'],i['testrun_result_id'],i['testrun_result_status'],i['time_taken']])
+                    click.echo(table)   
+                    if  fail_count==0:
+                        click.echo("All test cases from this testrun have passed. Please refer above table for more details.")
+                        exit()
+                    else: 
+                        click.echo(f"{fail_count} test cases from this testrun have failed. Please refer above table for more details.")
+                        exit(1)   
+
     else:
         click.echo(res2.json())
-        return 0
+        exit()
 
 # Command Group 
 @click.group(name='status')
@@ -247,10 +261,17 @@ def status(testrun_id):
 
     table = PrettyTable(["browser_name", "browser_version","test run result id", "status", "time taken"])
 
-    click.echo(f"\ntest status : {test_status}\n")
+    click.echo(f"\nTestrun Status : {test_status}\n")
+    fail_count = 0
     for i in testrun_status_details:
+        if i['testrun_result_status']=="fail":
+            fail_count+=1
         table.add_row([i['browser_name'],i['browser_version'],i['testrun_result_id'],i['testrun_result_status'],i['time_taken']])
-        # click.echo(f"   {i['browser_name']}-{i['browser_version']}    test run result id: {i['testrun_result_id']}   status: {i['testrun_result_status']}   time taken: {i['time_taken']} secs", )
-   
-    click.echo(table)
-    
\ No newline at end of file
+    click.echo(table)   
+    if  fail_count==0:
+        click.echo("All test cases from this testrun have passed. Please refer above table for more details.")
+        exit()
+    else: 
+        click.echo(f"{fail_count} test cases from this testrun have failed. Please refer above table for more details.")
+        exit(1)   
+
